@@ -61,7 +61,9 @@ class FritzProfileSwitch:
             profile_id = row.xpath('td[@class="btncolumn"]/button[@name="edit"]/@value')[0]
             if profile_name == self.profile_name:
                 return profile_id
-        return None
+        self.failed = True
+        raise AttributeError(
+            'The specified profile {} does not exist. Please check the spelling.'.format(self.profile_name))
 
     def get_state(self):
         url = self.url + '/data.lua'
@@ -69,7 +71,7 @@ class FritzProfileSwitch:
         r = requests.post(url, data=data, allow_redirects=True)
         if r.status_code != 200:
             # login again to fetch new sid
-            self.sid = self.login(self._user, self._password)
+            self.sid = self.login()
             data = {"sid": self.sid, "edit": self.profile_id, "page": "kids_profileedit"}
             r = requests.post(url, data=data, allow_redirects=True)
 
@@ -86,7 +88,7 @@ class FritzProfileSwitch:
 
         if r.status_code != 200:
             # login again to fetch new sid
-            self.sid = self.login(self._user, self._password)
+            self.sid = self.login()
             data = {"sid": self.sid, "edit": self.profile_id, "time": state, "budget": "unlimited", "apply": "",
                     "page": "kids_profileedit"}
             r = requests.post(url, data=data, allow_redirects=True)
